


ibmdbpy4nps - Custom Python ML/Analytics Inside Netezza

  Please check the full documentation here
  https://www.ibm.com/support/knowledgecenter/SSTNZ3/com.ibm.ips.doc/postgresql/pyida/pyida.html

